# -*- coding: utf-8 -*-
"""
xss_utils Django application initialization.
"""
from django.apps import AppConfig


class XssUtilsConfig(AppConfig):
    """
    Configuration for the xss_utils Django application.
    """

    name = 'xss_utils'



"""
Template tags and helper functions for escaping script tag.
"""
from django import template
from django.utils import html

register = template.Library()


@register.simple_tag(name="interpolate_html")
def interpolate_html(value, **kwargs):
    """
    Interpolates HTML into a string.

    Arguments:
        value (string): a string to escape and format.
        kwargs: named arguments to be formatted into the 'value' argument
            NOTE: kwargs will be escaped unless they are marked safe
            (Developers passing safe HTML as kwargs should first pass the value through the |safe filter)

    Returns:
        SafeString: A formatted and escaped version 'value' with all kwargs escaped appropriately
    """
    escaped_msg = html.escape(value)
    safe_interpolated_msg = html.format_html(escaped_msg, **kwargs)
    return safe_interpolated_msg



"""
Tests for templates tags.
"""

from django.http import HttpResponse
from django.template import Context, Template
from django.test import TestCase


class InterpolateHtmlFilterTest(TestCase):
    """ Class for interpolate_html filter escaping """
    def test_interpolate_html_escape_rendered(self):
        """ Verify interpolate_html filter escapes string with kwargs """
        context = Context({})
        template_to_render = Template(
            '{% load django_markup %}'
            '{% interpolate_html \"{s} message <script>alert(\'alert\')</script>{e}\" s="<p>"|safe e="</p>"|safe %}'
        )
        rendered_template = template_to_render.render(context)
        response = HttpResponse(rendered_template)

        self.assertContains(response, '&lt;script&gt;')
        self.assertContains(response, '<p>')
